#include <Adafruit_CircuitPlayground.h>
#include <Servo.h>

int flexPin = A6;  
int flexReading;   
int servoPosition;
int LswitchNegative = A2; // Limit switch pin for negative movement
int LswitchPositive = A4; // New limit switch pin for forward movement
Servo myServo;
Servo myServo2;

bool servo2Moving = false;      // Tracks whether the servo is moving
bool servo2Direction = true;    // Tracks the direction of myServo2 (true = forward, false = backward)
bool buttonPressed = false;     // Prevents multiple actions on a single button press

void setup(void) {
  Serial.begin(9600);   
  CircuitPlayground.begin();  // Initialize Circuit Playground
  myServo.attach(A3);         // Attach the first servo to pin A3
  myServo2.attach(A1);        // Attach the second servo to pin A1
  pinMode(LswitchNegative, INPUT_PULLUP); // Configure A2 limit switch with pull-up resistor
  pinMode(LswitchPositive, INPUT_PULLUP); // Configure A4 limit switch with pull-up resistor
}

void loop(void) {
  // Flex sensor logic for myServo
  flexReading = analogRead(flexPin);  
  servoPosition = map(flexReading, 600, 800, 0, 180);
  servoPosition = constrain(servoPosition, 0, 180);
  myServo.write(servoPosition);

  // Read the state of the limit switches
  int switchStateNegative = digitalRead(LswitchNegative); // Read A2 switch state
  int switchStatePositive = digitalRead(LswitchPositive); // Read A4 switch state

  // Handle the limit switch for negative movement (A2)
  if (switchStateNegative == LOW) {
    if (servo2Direction) {
      // If moving forward, briefly reverse
      Serial.println("A2 switch engaged while moving forward. Briefly reversing.");
      myServo2.write(-180); // Reverse speed
      delay(100);           // Reverse for 100 milliseconds
      myServo2.write(97);   // Stop the motor
      servo2Moving = false; // Mark servo as not moving
    } else {
      // If moving backward, stop
      Serial.println("A2 switch engaged while moving backward. Stopping.");
      myServo2.write(97);   // Neutral position (stationary)
      servo2Moving = false; // Mark servo as not moving
    }
  }

  // Handle the new limit switch for positive movement (A4)
  else if (switchStatePositive == LOW) {
    Serial.println("A4 switch engaged. Moving forward briefly.");
    myServo2.write(180); // Move forward
    delay(100);          // Move forward for 100 milliseconds
    myServo2.write(97);  // Stop the motor
    servo2Moving = false; // Mark servo as not moving
  }

  // Regular button logic (only if no switches are engaged)
  else {
    // Button A pressed (move forward)
    if (CircuitPlayground.leftButton() && !buttonPressed) {
      buttonPressed = true; // Mark button as pressed
      servo2Direction = true; // Set to forward
      servo2Moving = true;    // Start moving
      Serial.println("Button A pressed. Moving forward.");
    }

    // Button B pressed (move backward)
    if (CircuitPlayground.rightButton() && !buttonPressed) {
      buttonPressed = true; // Mark button as pressed
      servo2Direction = false; // Set to backward
      servo2Moving = true;     // Start moving
      Serial.println("Button B pressed. Moving backward.");
    }

    // Reset button pressed state when neither button is pressed
    if (!CircuitPlayground.leftButton() && !CircuitPlayground.rightButton()) {
      buttonPressed = false;
    }

    // Move the servo in the set direction if it's moving
    if (servo2Moving) {
      if (servo2Direction) {
        myServo2.write(180);  // Move forward
        Serial.println("myServo2 moving forward.");
      } else {
        myServo2.write(-180); // Move backward
        Serial.println("myServo2 moving backward.");
      }
    } else {
      myServo2.write(97); // Neutral position (stationary)
      Serial.println("myServo2 stopped.");
    }
  }

  Serial.print("Flex reading = ");
  Serial.println(flexReading);

  delay(20);
}
